import { world, MinecraftEnchantmentTypes, ItemStack, Items, Location } from "@minecraft/server"

//gets the player score value
function getPlayerScore(scoreboardValue, player) {
    return world.scoreboard.getObjective(scoreboardValue).getScore(player.scoreboard)
}

//function to summon xp orbs
function spawnXp(count, block) {
    for (let i = 0; i < count; i++) {
        block.dimension.spawnEntity("minecraft:xp_orb", block.block.location);
    }
    return;
};

//event that fires before a block explodes
world.events.beforeExplosion.subscribe((ev) => {
    let explodeType = 0;
    let ore = 0;
    let customOre = false;
    for (let i = 0; i < ev.impactedBlocks.length; i++) {
        ev.dimension.spawnEntity("minecraft:xp_orb", ev.dimension.getBlock(ev.impactedBlocks[i]).location);
        if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("rune_ore_block")) {
            ore = new ItemStack(Items.get('runecraft:rune_ore'), 1);
            customOre = true;
        }
        else if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("adamant_ore_block")) {
            ore = new ItemStack(Items.get('runecraft:adamant_ore'), 1);
            customOre = true;
        }
        else if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("mithril_ore_block")) {
            ore = new ItemStack(Items.get('runecraft:mithril_ore'), 1);
            customOre = true;
        }
        else if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("lapis_ore_block")) {
            ore = new ItemStack(Items.get('minecraft:lapis_lazuli'), 1);
            customOre = true;
        }
        else if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("emerald_ore_block")) {
            ore = new ItemStack(Items.get('minecraft:emerald'), 1);
            customOre = true;
        }
        else if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("gold_ore_block")) {
            ore = new ItemStack(Items.get('minecraft:raw_gold'), 1);
            customOre = true;
        }
        else if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("redstone_ore_block")) {
            ore = new ItemStack(Items.get('minecraft:redstone'), 1);
            customOre = true;
        }
        else if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("iron_ore_block")) {
            ore = new ItemStack(Items.get('minecraft:raw_iron'), 1);
            customOre = true;
        }
        else if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("tin_ore_block")) {
            ore = new ItemStack(Items.get('runecraft:tin_ore'), 1);
            customOre = true;
        }
        else if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("coal_ore_block")) {
            ore = new ItemStack(Items.get('minecraft:coal_ore'), 1);
            customOre = true;
        }
        else if (ev.dimension.getBlock(ev.impactedBlocks[i]).hasTag("copper_ore_block")) {
            ore = new ItemStack(Items.get('minecraft:raw_copper'), 1);
            customOre = true;
        }
        else {
            customOre = false;
        }
        //tnt
        if (ev.source.typeId == "minecraft:tnt") {
            explodeType = 1;
        }
        //creeper
        else if (ev.source.typeId == "minecraft:creeper" || ev.source.typeId == "minecraft:ender_crystal") {
            explodeType = 2;
            const isCharged = ev.source.getComponent("minecraft:is_charged");
            //charged creeper and end crystal
            if (isCharged == 0 || ev.source.typeId == "minecraft:ender_crystal") {
                explodeType = 3;
            }
        }
        explodeWeight(explodeType, ore, ev.dimension.getBlock(ev.impactedBlocks[i]), customOre);
    }
});

function spawnXpExplode(dim, location) {
    setTickTimeout(() => {
        dim.spawnEntity("minecraft:xp_orb", location)
    }, 1)
    return;
}

//calculates chance to spawn ore on explosion
function explodeWeight(explodeType, ore, currentBlock, customOre) {
    const dim = currentBlock.dimension;
    const blockLocation = new Location(currentBlock.location.x + 0.5, currentBlock.location.y + 0.4, currentBlock.location.z + 0.5);
    let weightCounter = 0;
    if (customOre) {
        switch (explodeType) {
            case 1:
                weightCounter = (Math.random() * 4) + 1
                if (weightCounter <= 2) {
                    dim.spawnItem(ore, blockLocation);
                    spawnXpExplode(dim, currentBlock.location);
                }
                break;
            case 2:
                weightCounter = (Math.random() * 3) + 1
                if (weightCounter <= 2) {
                    dim.spawnItem(ore, blockLocation);
                    spawnXpExplode(dim, currentBlock.location);
                }
                break;
            case 3:
                weightCounter = (Math.random() * 6) + 1
                if (weightCounter <= 2) {
                    dim.spawnItem(ore, blockLocation);
                    spawnXpExplode(dim, currentBlock.location);
                }
                break;
        }
    }
}

//spawns the ore
function spawnLoot(count, oreType, blockLocation, block) {
    for (let i = 0; i < count; i++) {
        block.dimension.spawnItem(oreType, blockLocation);
    }
    return;
}

//calculates the chance to spawn ore
function fortuneWeight(fortuneLevel, block, ore, blockLocation) {
    let weightCounter = 0;
    switch (fortuneLevel) {
        case 0:
            block.dimension.spawnItem(ore, blockLocation);
            break;
        case 1:
            weightCounter = (Math.random() * 3)
            if (weightCounter >= 2) {
                spawnLoot(2, ore, blockLocation, block)
            }
            else {
                block.dimension.spawnItem(ore, blockLocation);
            }
            break;
        case 2:
            weightCounter = (Math.random() * 8)
            if (weightCounter >= 6) {
                spawnLoot(3, ore, blockLocation, block)
            }
            else if (weightCounter >= 4) {
                spawnLoot(2, ore, blockLocation, block)
            }
            else {
                block.dimension.spawnItem(ore, blockLocation);
            }
            break;
        case 3:
            weightCounter = (Math.random() * 10)
            if (weightCounter >= 8) {
                spawnLoot(4, ore, blockLocation, block)
            }
            else if (weightCounter >= 6) {
                spawnLoot(3, ore, blockLocation, block)
            }
            else if (weightCounter >= 4) {
                spawnLoot(2, ore, blockLocation, block)
            }
            else {
                block.dimension.spawnItem(ore, blockLocation);
            }
            break;
    }
    let partyHatChance = 0;
    partyHatChance = Math.random() * 5000;
    if (partyHatChance == 1) {
        const partyHat = new ItemStack(Items.get('runecraft:silver_party_hat'), 1);
        block.dimension.spawnItem(partyHat, blockLocation)
    }
    return;
}

//triggers when a block is mined
world.events.blockBreak.subscribe((block) => {
    //variable used to account for loot table rolls
    let weightCounter = 0;

    //const blockBroken = block.brokenBlockPermutation.type.id;
    const player = block.player;

    const item = player?.getComponent("minecraft:inventory").container.getItem(player.selectedSlot);
    //if (item == null) return;
    //const enchComp = item.getComponent("enchantments").enchantments;

    //check for silk touch enchantment presence
    //const isSilkTouch = enchComp.hasEnchantment(MinecraftEnchantmentTypes.silkTouch);
    //let random = Math.round((Math.random() * 2) + 1);

    //check for fortune enchantment presence, acquire level if present
    /* enchComp.hasEnchantment(MinecraftEnchantmentTypes.fortune); should typically only return 1 or 0 if the tool HAS fortune, but it is returning the actual enchantment level.
       This next section will need to be modified if the bug is fixed. It should be enchComp.hasEnchantment(MinecraftEnchantmentTypes.fortune).level;*/
    //const fortuneLevel = enchComp.hasEnchantment(MinecraftEnchantmentTypes.fortune);
    let isSilkTouch = 0;
    let fortuneLevel = 0;
    if(item != null) {
        isSilkTouch = item.getComponent("enchantments").enchantments.hasEnchantment(MinecraftEnchantmentTypes.silkTouch);
        fortuneLevel = item.getComponent("enchantments").enchantments.hasEnchantment(MinecraftEnchantmentTypes.fortune);
    }
    //acquire mining level scoreboard value of the player
    const miningLevel = getPlayerScore("mining_level", player);

    //rune ore
    if (isSilkTouch == 0) {
        const blockLocation = new Location(block.block.location.x + 0.5, block.block.location.y + 0.4, block.block.location.z + 0.5);
        if (block.brokenBlockPermutation.hasTag("rune_ore_block")) {
            if ((item?.typeId == "runecraft:rune_pickaxe" && miningLevel >= 60) || (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel >= 50)) {
                //calculate and spawn XP orbs
                let number = (Math.random() * 5) + 1;
                spawnXp(number, block);

                //make the rune ore item
                const ore = new ItemStack(Items.get('runecraft:rune_ore'), 1);

                //calculates the weight, then calls spawnLoot() to spawn the items
                fortuneWeight(fortuneLevel, block, ore, blockLocation);

                //give the player mining xp
                if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                    player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 290);
                    player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 290);
                    player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 290);

                }
            }
            //is not using the correct pickaxe
            else {
                player.tell(`\u00A7cAn Adamant Pickaxe or better is required to mine Rune Ore.`);
                return;
            }

        }
        else if (block.brokenBlockPermutation.hasTag("adamant_ore_block")) {
            if ((item?.typeId == "runecraft:rune_pickaxe" && miningLevel >= 60) || (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel >= 50) || (item?.typeId == "runecraft:mithril_pickaxe" && miningLevel >= 40)) {
                //calculate and spawn XP orbs
                let number = (Math.random() * 4) + 1;
                spawnXp(number, block);

                //make the rune ore item
                const ore = new ItemStack(Items.get('runecraft:adamant_ore'), 1);

                fortuneWeight(fortuneLevel, block, ore, blockLocation);
                //give the player mining xp
                if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                    player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 210);
                    player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 210);
                    player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 210);
                }
            }
            //is not using the correct pickaxe
            else {
                player.tell(`\u00A7cA Mithril Pickaxe or better is required to mine Adamant Ore.`);
                return;
            }

        }
        else if (block.brokenBlockPermutation.hasTag("mithril_ore_block")) {
            if ((item?.typeId == "runecraft:rune_pickaxe" && miningLevel >= 60) || (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel >= 50) || (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel >= 40) || (item?.typeId == "runecraft:steel_pickaxe" && miningLevel >= 30)) {
                //calculate and spawn XP orbs
                let number = (Math.random() * 3) + 1;
                spawnXp(number, block);

                //make the rune ore item
                const ore = new ItemStack(Items.get('runecraft:mithril_ore'), 1);

                fortuneWeight(fortuneLevel, block, ore, blockLocation);
                //give the player mining xp
                if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                    player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 150);
                    player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 150);
                    player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 150);
                }
            }
            //is not using the correct pickaxe
            else {
                player.tell(`\u00A7cA Steel Pickaxe or better is required to mine Mithril Ore.`);
                return;
            }

        }
        else if (block.brokenBlockPermutation.hasTag("lapis_ore_block") || block.brokenBlockPermutation.hasTag("emerald_ore_block") || block.brokenBlockPermutation.hasTag("gold_ore_block") || block.brokenBlockPermutation.hasTag("redstone_ore_block")) {
            if ((item?.typeId == "runecraft:rune_pickaxe" && miningLevel >= 60) || (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel >= 50) || (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel >= 40) || (item?.typeId == "runecraft:steel_pickaxe" && miningLevel >= 30) || (item?.typeId == "runecraft:iron_pickaxe" && miningLevel >= 20) || (item?.typeId == "runecraft:black_pickaxe" && miningLevel >= 20)) {
                //calculate and spawn XP orbs
                let number = (Math.random() * 2) + 1;
                spawnXp(number, block);

                let ore = 0;
                //make the rune ore item
                if (block.brokenBlockPermutation.hasTag("lapis_ore_block")) {
                    ore = new ItemStack(Items.get('minecraft:lapis_lazuli'), 1);
                    switch (fortuneLevel) {
                        case 0:
                            weightCounter = (Math.random() * 2)
                            if (weightCounter >= 1) {
                                spawnLoot(5, ore, blockLocation, block)
                            }
                            else {
                                spawnLoot(4, ore, blockLocation, block)
                            }
                            break;
                        case 1:
                            weightCounter = (Math.random() * 3)
                            if (weightCounter >= 2) {
                                spawnLoot(6, ore, blockLocation, block)
                            }
                            else if (weightCounter >= 1) {
                                spawnLoot(5, ore, blockLocation, block)
                            }
                            else {
                                spawnLoot(4, ore, blockLocation, block)
                            }
                            break;
                        case 2:
                            weightCounter = (Math.random() * 6)
                            if (weightCounter >= 4) {
                                spawnLoot(4, ore, blockLocation, block)
                            }
                            else if (weightCounter >= 3) {
                                spawnLoot(5, ore, blockLocation, block)
                            }
                            else if (weightCounter >= 2) {
                                spawnLoot(6, ore, blockLocation, block)
                            }
                            else {
                                spawnLoot(7, ore, blockLocation, block)
                            }
                            break;
                        case 3:
                            weightCounter = (Math.random() * 6)
                            if (weightCounter >= 4) {
                                spawnLoot(4, ore, blockLocation, block)
                            }
                            else if (weightCounter == 3) {
                                spawnLoot(5, ore, blockLocation, block)
                            }
                            else if (weightCounter >= 1) {
                                spawnLoot(8, ore, blockLocation, block)
                            }
                            else {
                                spawnLoot(7, ore, blockLocation, block)
                            }
                            break;
                    }
                }
                else if (block.brokenBlockPermutation.hasTag("emerald_ore_block")) {
                    ore = new ItemStack(Items.get('minecraft:emerald'), 1);
                    fortuneWeight(fortuneLevel, block, ore, blockLocation);
                }
                else if (block.brokenBlockPermutation.hasTag("gold_ore_block")) {
                    ore = new ItemStack(Items.get('minecraft:raw_gold'), 1);
                    fortuneWeight(fortuneLevel, block, ore, blockLocation);
                }
                else if (block.brokenBlockPermutation.hasTag("redstone_ore_block")) {
                    ore = new ItemStack(Items.get('minecraft:redstone'), 1);
                    switch (fortuneLevel) {
                        case 0:
                            weightCounter = (Math.random() * 2)
                            if (weightCounter >= 1) {
                                spawnLoot(5, ore, blockLocation, block)
                            }
                            else {
                                spawnLoot(4, ore, blockLocation, block)
                            }
                            break;
                        case 1:
                            weightCounter = (Math.random() * 3)
                            if (weightCounter >= 2) {
                                spawnLoot(6, ore, blockLocation, block)
                            }
                            else if (weightCounter >= 1) {
                                spawnLoot(5, ore, blockLocation, block)
                            }
                            else {
                                spawnLoot(4, ore, blockLocation, block)
                            }
                            break;
                        case 2:
                            weightCounter = (Math.random() * 6)
                            if (weightCounter >= 4) {
                                spawnLoot(4, ore, blockLocation, block)
                            }
                            else if (weightCounter >= 3) {
                                spawnLoot(5, ore, blockLocation, block)
                            }
                            else if (weightCounter >= 2) {
                                spawnLoot(6, ore, blockLocation, block)
                            }
                            else {
                                spawnLoot(7, ore, blockLocation, block)
                            }
                            break;
                        case 3:
                            weightCounter = (Math.random() * 6)
                            if (weightCounter >= 4) {
                                spawnLoot(4, ore, blockLocation, block)
                            }
                            else if (weightCounter == 3) {
                                spawnLoot(5, ore, blockLocation, block)
                            }
                            else if (weightCounter >= 1) {
                                spawnLoot(8, ore, blockLocation, block)
                            }
                            else {
                                spawnLoot(7, ore, blockLocation, block)
                            }
                            break;
                    }
                }

                if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                    player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 100);
                    player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 100);
                    player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 100);
                }
                //is not using the correct pickaxe
            }
            else {
                if (block.brokenBlockPermutation.hasTag("lapis_ore_block")) {
                    player.tell(`\u00A7cAn Iron Pickaxe or better is required to mine Lapis Ore.`);
                }
                else if (block.brokenBlockPermutation.hasTag("emerald_ore_block")) {
                    player.tell(`\u00A7cAn Iron Pickaxe or better is required to mine Emerald Ore.`);
                }
                else if (block.brokenBlockPermutation.hasTag("gold_ore_block")) {
                    player.tell(`\u00A7cAn Iron Pickaxe or better is required to mine Gold Ore.`);
                }
                else if (block.brokenBlockPermutation.hasTag("redstone_ore_block")) {
                    player.tell(`\u00A7cAn Iron Pickaxe or better is required to mine Redstone Ore.`);
                }
                return;
            }
        }
        else if (block.brokenBlockPermutation.hasTag("iron_ore_block")) {
            if ((item?.typeId == "runecraft:rune_pickaxe" && miningLevel >= 60) || (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel >= 50) || (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel >= 40) || (item?.typeId == "runecraft:steel_pickaxe" && miningLevel >= 30) || (item?.typeId == "runecraft:iron_pickaxe" && miningLevel >= 20) || (item?.typeId == "runecraft:black_pickaxe" && miningLevel >= 20) || (item?.typeId == "runecraft:bronze_pickaxe" && miningLevel >= 10)) {
                //calculate and spawn XP orbs
                let number = (Math.random() * 2) + 1;
                spawnXp(number, block);

                //make the ore item
                const ore = new ItemStack(Items.get('minecraft:raw_iron'), 1);


                fortuneWeight(fortuneLevel, block, ore, blockLocation);
                //give the player mining xp
                if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                    player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 100);
                    player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 100);
                    player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 100);
                }
            }
            //is not using the correct pickaxe
            else {
                player.tell(`\u00A7cA Bronze Pickaxe or better is required to mine Iron Ore.`);
                return;
            }
        }
        else if (block.brokenBlockPermutation.hasTag("coal_ore_block") || block.brokenBlockPermutation.hasTag("tin_ore_block") || block.brokenBlockPermutation.hasTag("copper_ore_block")) {
            if ((item?.typeId == "runecraft:rune_pickaxe" && miningLevel >= 60) || (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel >= 50) || (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel >= 40) || (item?.typeId == "runecraft:steel_pickaxe" && miningLevel >= 30) || (item?.typeId == "runecraft:iron_pickaxe" && miningLevel >= 20) || (item?.typeId == "runecraft:black_pickaxe" && miningLevel >= 20) || (item?.typeId == "runecraft:bronze_pickaxe" && miningLevel >= 10) || (item?.typeId == "runecraft:wooden_pickaxe")) {
                //calculate and spawn XP orbs
                let number = (Math.random() * 2) + 1;
                spawnXp(number, block);

                //make the ore item
                let ore = 0;
                //make the rune ore item
                if (block.brokenBlockPermutation.hasTag("coal_ore_block")) {
                    ore = new ItemStack(Items.get('minecraft:coal'), 1);
                }
                else if (block.brokenBlockPermutation.hasTag("tin_ore_block")) {
                    ore = new ItemStack(Items.get('runecraft:tin_ore'), 1);
                }
                else if (block.brokenBlockPermutation.hasTag("copper_ore_block")) {
                    ore = new ItemStack(Items.get('minecraft:raw_copper'), 1);
                }


                fortuneWeight(fortuneLevel, block, ore, blockLocation);
                //give the player mining xp
                if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                    player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 30);
                    player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 30);
                    player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 30);
                }
            }
            //is not using the correct pickaxe
            else {
                if (block.brokenBlockPermutation.hasTag("coal_ore_block")) {
                    player.tell(`§o§eRequired to mine Coal Ore: Any Pickaxe.`);
                }
                else if (block.brokenBlockPermutation.hasTag("tin_ore_block")) {
                    player.tell(`§o§eRequired to mine Tin Ore: Any Pickaxe.`);
                }
                else if (block.brokenBlockPermutation.hasTag("copper_ore_block")) {
                    player.tell(`§o§eRequired to mine Copper Ore: Any Pickaxe.`);
                }
            }
        }
        //can't use a rune pickaxe
        else if (item?.typeId == "runecraft:rune_pickaxe" && miningLevel < 60) {
            player.tell(`\u00A7cLevel 60 Mining is required to use a Rune Pickaxe.`);
            return;
        }
        //cant use an adamant pickaxe
        else if (item?.typeId == "runecraft:adamant_pickaxe" && miningLevel < 50) {
            player.tell(`\u00A7cLevel 50 Mining is required to use an Adamant Pickaxe.`);
            return;
        }
        //cant use an mithril pickaxe
        else if (item?.typeId == "runecraft:mithril_pickaxe" && miningLevel < 40) {
            player.tell(`\u00A7cLevel 40 Mining is required to use a mithril Pickaxe.`);
            return;
        }
        //cant use an steel pickaxe
        else if (item?.typeId == "runecraft:steel_pickaxe" && miningLevel < 30) {
            player.tell(`\u00A7cLevel 30 Mining is required to use a Steel Pickaxe.`);
            return;
        }
        //cant use an iron pickaxe
        else if (item?.typeId == "runecraft:iron_pickaxe" && miningLevel < 20) {
            player.tell(`\u00A7cLevel 20 Mining is required to use an Iron Pickaxe.`);
            return;
        }
        //cant use an black pickaxe
        else if (item?.typeId == "runecraft:black_pickaxe" && miningLevel < 20) {
            player.tell(`\u00A7cLevel 20 Mining is required to use a Black Pickaxe.`);
            return;
        }
        //cant use an bronze pickaxe
        else if (item?.typeId == "runecraft:bronze" && miningLevel < 10) {
            player.tell(`\u00A7cLevel 10 Mining is required to use a Bronze Pickaxe.`);
            return;
        }
        if (((item.typeId == "runecraft:wooden_axe" || item.typeId == "runecraft:bronze_axe" || item.typeId == "runecraft:iron_axe" || item.typeId == "runecraft:black_axe" || item.typeId == "runecraft:steel_axe" || item.typeId == "runecraft:mithril_axe" || item.typeId == "runecraft:adamant_axe" || item.typeId == "runecraft:rune_axe") && isSilkTouch == 0)) {
            switch (block.brokenBlockPermutation.type.id) {
                case "minecraft:log":
                case "minecraft:mangrove_log":
                case "minecraft:log2":
                case "minecraft:crimson_stem":
                case "minecraft:warped_stem":
                    if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                        player.scoreboard.setScore(world.scoreboard.getObjective('woodcutting_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('woodcutting_xp_c')) + 50);
                        player.scoreboard.setScore(world.scoreboard.getObjective('tot_woodcut_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_woodcut_xp')) + 50);
                        player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 50);
                    }
                    break;
            }
        };
        if (((item.typeId == "runecraft:wooden_shovel" || item.typeId == "runecraft:bronze_shovel" || item.typeId == "runecraft:iron_shovel" || item.typeId == "runecraft:black_shovel" || item.typeId == "runecraft:steel_shovel" || item.typeId == "runecraft:mithril_shovel" || item.typeId == "runecraft:adamant_shovel" || item.typeId == "runecraft:rune_shovel") && isSilkTouch == 0)) {
            switch (block.brokenBlockPermutation.type.id) {
                case "minecraft:clay":
                case "minecraft:dirt_with_roots":
                case "minecraft:dirt":
                case "minecraft:grass":
                case "minecraft:gravel":
                case "minecraft:mycelium":
                case "minecraft:podzol":
                case "minecraft:sand":
                case "minecraft:snow":
                case "minecraft:powder_snow":
                case "minecraft:soul_sand":
                case "minecraft:soul_soil":
                    //WHERE IS COARSE DIRT GUYS
                    //case "minecraft:coarse_dirt":
                    if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                        player.scoreboard.setScore(world.scoreboard.getObjective('digging_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('digging_xp_c')) + 30);
                        player.scoreboard.setScore(world.scoreboard.getObjective('tot_digging_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_digging_xp')) + 30);
                        player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 30);
                    }
                    break;
            }
        };
        if (((item.typeId == "runecraft:wooden_pickaxe" || item.typeId == "runecraft:bronze_pickaxe" || item.typeId == "runecraft:iron_pickaxe" || item.typeId == "runecraft:black_pickaxe" || item.typeId == "runecraft:steel_pickaxe" || item.typeId == "runecraft:mithril_pickaxe" || item.typeId == "runecraft:adamant_pickaxe" || item.typeId == "runecraft:rune_pickaxe") && isSilkTouch == 0)) {
            switch (block.brokenBlockPermutation.type.id) {
                case "minecraft:stone":
                case "minecraft:sandstone":
                case "minecraft:end_stone":
                case "minecraft:dripstone_block":
                case "minecraft:deepslate":
                case "minecraft:tuff":
                case "minecraft:pointed_dripstone":
                case "minecraft:netherrack":
                case "minecraft:basalt":
                case "minecraft:blackstone":
                case "minecraft:crimson_nylium":
                case "minecrafT:warped_nylium":
                    if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                        player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 2);
                        player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 2);
                        player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 2);
                    }
                    break;
                case "minecraft:quartz_ore":
                    if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                        player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 30);
                        player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 30);
                        player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 30);
                    }
                    break;
                case "minecraft:amethyst_cluster":
                    if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                        player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 350);
                        player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 350);
                        player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 350);
                    }
                    break;
                case "minecraft:small_amethyst_bud":
                    if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                        player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 50);
                        player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 50);
                        player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 50);
                    }
                    break;
                case "minecraft:medium_amethyst_bud":
                    if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                        player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 150);
                        player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 150);
                        player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 150);
                    }
                    break;
                case "minecraft:large_amethyst_bud":
                    if (player.scoreboard.getScore(world.scoreboard.getObjective('gamemode')) <= 2) {
                        player.scoreboard.setScore(world.scoreboard.getObjective('mining_xp_c'), player.scoreboard.getScore(world.scoreboard.getObjective('mining_xp_c')) + 250);
                        player.scoreboard.setScore(world.scoreboard.getObjective('tot_mining_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('tot_mining_xp')) + 250);
                        player.scoreboard.setScore(world.scoreboard.getObjective('total_xp'), player.scoreboard.getScore(world.scoreboard.getObjective('total_xp')) + 250);
                    }
                    break;
            }
        };

    }
})