import { world, ItemStack, Items, Location, system, BlockLocation } from "@minecraft/server"

const blockMap = new Map();

system.events.scriptEventReceive.subscribe((event) => {
    if (event.id == "runecraft:mob_head") {
        const block = event.sourceBlock;
        const blockBelow = block.dimension.getBlock(new BlockLocation(Math.floor(block.location.x), Math.floor(block.location.y) - 1, Math.floor(block.location.z)))
        const currentRedstonePower = blockBelow.getRedstonePower();
        const { x, y, z } = blockBelow.location
        const blockKey = `${x}*${y}*${z}`
        const blockObject = blockMap.get(blockKey) ?? {};
        const { previousRedstonePower } = blockObject;

        if (blockBelow.typeId == "minecraft:noteblock" && currentRedstonePower > 0 && currentRedstonePower != previousRedstonePower) {
            const location = new Location(blockBelow.location.x, blockBelow.location.y, blockBelow.location.z)
            if (block.type.id == "runecraft:witch_head_block") {
                world.playSound("mob.witch.ambient", { location });
            }
            else if (block.type.id == "runecraft:panda_head_block") {
                world.playSound("mob.panda.eat", { location });
            }
            else if (block.type.id == "runecraft:panda_head_brown_block") {
                world.playSound("mob.panda.sneeze", { location });
            }
            else if (block.type.id == "runecraft:llama_head_white_block") {
                world.playSound("mob.llama.idle", { location });
            }
            else if (block.type.id == "runecraft:llama_head_gray_block") {
                world.playSound("mob.llama.hurt", { location });
            }
            else if (block.type.id == "runecraft:llama_head_brown_block") {
                world.playSound("mob.llama.spit", { location });
            }
            else if (block.type.id == "runecraft:llama_head_cream_block") {
                world.playSound("mob.llama.angry", { location });
            }
        }
        blockObject.previousRedstonePower = currentRedstonePower;
        blockMap.set(blockKey, blockObject)
    }
});

world.events.beforeItemUseOn.subscribe((eventData) => {
    const block = eventData.source.dimension.getBlock(eventData.blockLocation);
    const blockAbove = eventData.source.dimension.getBlock(new BlockLocation(Math.floor(block.location.x), Math.floor(block.location.y) + 1, Math.floor(block.location.z)))
    if (block.type.id == "minecraft:noteblock") {
        const location = new Location(block.location.x, block.location.y, block.location.z)
        if (blockAbove.type.id == "runecraft:witch_head_block") {
            world.playSound("mob.witch.ambient", { location });
        }
        else if (blockAbove.type.id == "runecraft:panda_head_block") {
            world.playSound("mob.panda.eat", { location });
        }
        else if (blockAbove.type.id == "runecraft:panda_head_brown_block") {
            world.playSound("mob.panda.sneeze", { location });
        }
        else if (blockAbove.type.id == "runecraft:llama_head_white_block") {
            world.playSound("mob.llama.idle", { location });
        }
        else if (blockAbove.type.id == "runecraft:llama_head_gray_block") {
            world.playSound("mob.llama.hurt", { location });
        }
        else if (blockAbove.type.id == "runecraft:llama_head_brown_block") {
            world.playSound("mob.llama.spit", { location });
        }
        else if (blockAbove.type.id == "runecraft:llama_head_cream_block") {
            world.playSound("mob.llama.angry", { location });
        }
    }
})

//SECTION TO DROP MOB HEADS WHEN BROKEN (Because silk touch is non functional for detection in loot tables and sucks major nuts)
world.events.blockBreak.subscribe((block) => {
    const blockLocation = new Location(block.block.location.x + 0.5, block.block.location.y + 0.4, block.block.location.z + 0.5);
    if (block.brokenBlockPermutation.hasTag("witch_head")) {
        const itemToDrop = new ItemStack(Items.get('runecraft:witch_head'), 1);
        block.dimension.spawnItem(itemToDrop, blockLocation)
    }
    else if (block.brokenBlockPermutation.hasTag("panda_head")) {
        const itemToDrop = new ItemStack(Items.get('runecraft:panda_head'), 1);
        block.dimension.spawnItem(itemToDrop, blockLocation)
    }
    else if (block.brokenBlockPermutation.hasTag("panda_head_brown")) {
        const itemToDrop = new ItemStack(Items.get('runecraft:panda_head_brown'), 1);
        block.dimension.spawnItem(itemToDrop, blockLocation)
    }
    else if (block.brokenBlockPermutation.hasTag("llama_head_cream")) {
        const itemToDrop = new ItemStack(Items.get('runecraft:llama_head_cream'), 1);
        block.dimension.spawnItem(itemToDrop, blockLocation)
    }
    else if (block.brokenBlockPermutation.hasTag("llama_head_white")) {
        const itemToDrop = new ItemStack(Items.get('runecraft:llama_head_white'), 1);
        block.dimension.spawnItem(itemToDrop, blockLocation)
    }
    else if (block.brokenBlockPermutation.hasTag("llama_head_brown")) {
        const itemToDrop = new ItemStack(Items.get('runecraft:llama_head_brown'), 1);
        block.dimension.spawnItem(itemToDrop, blockLocation)
    }
    else if (block.brokenBlockPermutation.hasTag("llama_head_gray")) {
        const itemToDrop = new ItemStack(Items.get('runecraft:llama_head_gray'), 1);
        block.dimension.spawnItem(itemToDrop, blockLocation)
    }
})

//SECTION TO DROP MOB HEADS WHEN BLOWN UP (necessary because silk touch is non functional for detection in loot tables and sucks major FAT nuts)
world.events.beforeExplosion.subscribe((block) => {
    for (let i = 0; i < block.impactedBlocks.length; i++) {
        const blockLocation = new Location(block.dimension.getBlock(block.impactedBlocks[i]).location.x + 0.5, block.dimension.getBlock(block.impactedBlocks[i]).location.y + 0.4, block.dimension.getBlock(block.impactedBlocks[i]).location.z + 0.5);
        if (block.dimension.getBlock(block.impactedBlocks[i]).hasTag("witch_head")) {
            const itemToDrop = new ItemStack(Items.get('runecraft:witch_head'), 1);
            block.dimension.spawnItem(itemToDrop, blockLocation)
        }
        else if (block.dimension.getBlock(block.impactedBlocks[i]).hasTag("panda_head")) {
            const itemToDrop = new ItemStack(Items.get('runecraft:panda_head'), 1);
            block.dimension.spawnItem(itemToDrop, blockLocation)
        }
        else if (block.dimension.getBlock(block.impactedBlocks[i]).hasTag("panda_head_brown")) {
            const itemToDrop = new ItemStack(Items.get('runecraft:panda_head_brown'), 1);
            block.dimension.spawnItem(itemToDrop, blockLocation)
        }
        else if (block.dimension.getBlock(block.impactedBlocks[i]).hasTag("llama_head_cream")) {
            const itemToDrop = new ItemStack(Items.get('runecraft:llama_head_cream'), 1);
            block.dimension.spawnItem(itemToDrop, blockLocation)
        }
        else if (block.dimension.getBlock(block.impactedBlocks[i]).hasTag("llama_head_white")) {
            const itemToDrop = new ItemStack(Items.get('runecraft:llama_head_white'), 1);
            block.dimension.spawnItem(itemToDrop, blockLocation)
        }
        else if (block.dimension.getBlock(block.impactedBlocks[i]).hasTag("llama_head_brown")) {
            const itemToDrop = new ItemStack(Items.get('runecraft:llama_head_brown'), 1);
            block.dimension.spawnItem(itemToDrop, blockLocation)
        }
        else if (block.dimension.getBlock(block.impactedBlocks[i]).hasTag("llama_head_gray")) {
            const itemToDrop = new ItemStack(Items.get('runecraft:llama_head_gray'), 1);
            block.dimension.spawnItem(itemToDrop, blockLocation)
        }
    }
});

//PANDA HEAD
world.events.entityHurt.subscribe((eventData) => {
    if (eventData.damagingEntity) {
        if (eventData.hurtEntity.getComponent("minecraft:health").current <= 0) {

            const entityLocation = new Location(eventData.hurtEntity.location.x + 0.5, eventData.hurtEntity.location.y + 0.5, eventData.hurtEntity.location.z + 0.5);

            if (eventData.hurtEntity.typeId == "minecraft:panda" && eventData.damagingEntity.getComponent("minecraft:inventory").container.getItem(eventData.damagingEntity.selectedSlot).typeId == "minecraft:bamboo") {
               
                //normal panda head
                if (eventData.hurtEntity.getComponent("minecraft:variant").value != 4) {
                    const itemToDrop = new ItemStack(Items.get('runecraft:panda_head'));
                    eventData.hurtEntity.dimension.spawnItem(itemToDrop,entityLocation)
                }
                //brown panda
                else {
                    const itemToDrop = new ItemStack(Items.get('runecraft:panda_head_brown'));
                    eventData.hurtEntity.dimension.spawnItem(itemToDrop,entityLocation)
                }
            }
        }
    }
})

