import { world, MinecraftEffectTypes } from "@minecraft/server";
import { ActionFormData } from "@minecraft/server-ui";

//gets the player score value
function getPlayerScore(scoreboardValue, player) {
    return world.scoreboard.getObjective(scoreboardValue).getScore(player.scoreboard)
}

//Prayer Handling
world.events.beforeItemUse.subscribe((eventData) => {
    const item = eventData.item.typeId;
    const player = eventData.source;
    const block = eventData.source.getBlockFromViewDirection()?.type.id;
    //Using Book
    if(block == "runecraft:chaos_altar" || block == "runecraft:gilded_altar") {
        player.runCommandAsync("scoreboard players operation @s prayer_main = @s prayer_max")
        if(item == "runecraft:prayer_book") {
            if(getPlayerScore("prayer_level", player) >= 5) {
                prayerLoadoutSelection(eventData.source);
            }
            else {
                player.tell(`\u00A7cPrayers are unlocked at level 5.`);
            }
            
        }
    }
    else if (item == "runecraft:prayer_book") {

        const player = eventData.source;
        const prayerAmount = getPlayerScore("prayer_main", player);
        const prayerCost = getPlayerScore("pray_tot_cost", player);
        const activeState = getPlayerScore("prayer_active", player);
        const gamemode = getPlayerScore("gamemode", player);

        if (gamemode > 2) {
            player.tell(`\u00A7cPrayers can only be activated in survival.`);
        }
        else if (activeState == 0) {

            //not enough points to activate prayers
            if (prayerAmount < prayerCost) {
                player.tell(`\u00A7cNot enough Prayer Points to activate selected Prayers.`);
            }

            //no prayers selected in the equipped loadout
            else if (prayerCost == 0) {
                player.tell(`\u00A7cNo Prayers selected.`);
            }
            //prayers activated
            else {
                player.runCommandAsync("scoreboard players set @s prayer_active 1");
                player.playSound(`beacon.activate`);
            }
        }
        //prayers deactivated
        else {
            player.runCommandAsync("scoreboard players set @s prayer_active 0");
            player.playSound(`beacon.deactivate`);
        }
    }
})

world.events.beforeItemUseOn.subscribe((eventData) => {
    checkForBones(eventData.source,eventData.source.getBlockFromViewDirection().type.id, eventData.item.typeId)
})
function checkForBones(player, block, item) {    
    if(item == "runecraft:bones") {
        giveBoneXp(player, 17, block);
    }
    else if(item == "runecraft:big_bones") {
        giveBoneXp(player, 34, block);
    }
    else if (item == "runecraft:slime_remains") {
        giveBoneXp(player, 36, block);
    }
    else if(item == "runecraft:burnt_bones") {
        giveBoneXp(player, 45, block)
    }
    else if(item == "runecraft:magma_cube_remains") {
        giveBoneXp(player, 62, block)
    }
    else if(item == "runecraft:shade_remains") {
        giveBoneXp(player, 77, block)
    }
    else if(item == "runecraft:ghast_remains") {
        giveBoneXp(player, 87, block)
    }
    else if(item == "runecraft:warden_core") {
        giveBoneXp(player, 250, block)
    }
    else if(item == "runecraft:dragon_bones") {
        giveBoneXp(player, 2000, block)
    }
    else if(item == "runecraft:wither_spine") {
        giveBoneXp(player, 2000, block)
    }
    return;
}

function giveBoneXp(player, XpAmount, block) {
    if(block == "runecraft:chaos_altar") {
        player.runCommandAsync(`scoreboard players add @s[scores={gamemode=1..2}] prayer_xp_c ${XpAmount * 3}`)
        player.runCommandAsync(`scoreboard players add @s[scores={gamemode=1..2}] tot_prayer_xp ${XpAmount * 3}`)
        player.runCommandAsync(`scoreboard players add @s[scores={gamemode=1..2}] tot_xp ${XpAmount * 3}`)
        if(((Math.random() * 100) + 1) <= 15) {
            player.addEffect(MinecraftEffectTypes.wither, 80, 1, false);
        }
    }
    else if(block == "runecraft:gilded_altar") {
        player.runCommandAsync(`scoreboard players add @s[scores={gamemode=1..2}] prayer_xp_c ${XpAmount * 2}`)
        player.runCommandAsync(`scoreboard players add @s[scores={gamemode=1..2}] tot_prayer_xp ${XpAmount * 2}`)
        player.runCommandAsync(`scoreboard players add @s[scores={gamemode=1..2}] tot_xp ${XpAmount * 2}`)
    }
    else {
        player.runCommandAsync(`scoreboard players add @s[scores={gamemode=1..2}] prayer_xp_c ${XpAmount}`)
        player.runCommandAsync(`scoreboard players add @s[scores={gamemode=1..2}] tot_prayer_xp ${XpAmount}`)
        player.runCommandAsync(`scoreboard players add @s[scores={gamemode=1..2}] tot_xp ${XpAmount}`)
    }
}
//global use for referencing list of usable prayers + tiers
const prayerNamesWithTier = [
    "§cEmpty",
    "§dJump Boost 1 §a[Tier 1]",
    "§dStamina Regeneration 1 §a[Tier 1]",
    "§dRegeneration 1 §a[Tier 1]",
    "§dSpeed 1 §a[Tier 1]",
    "§dStrength 1 §a[Tier 1]",
    "§dResistance 1 §a[Tier 1]",
    "§dLevitation 1 §a[Tier 1]",
    "§dSlow Falling 1 §a[Tier 1]",
    "§dWater Breathing 1 §a[Tier 1]",
    "§dInvisibility 1 §a[Tier 1]",
    "§dFire Resistance 1 §b[Tier 2]",
    "§dJump Boost 2 §b[Tier 2]",
    "§dStamina Regeneration 2 §b[Tier 2]",
    "§dRegeneration 2 §b[Tier 2]",
    "§dSpeed 2 §b[Tier 2]",
    "§dStrength 2 §b[Tier 2]",
    "§dResistance 2 §b[Tier 2]",
    "§dHaste 1 §b[Tier 2]"
]

//Prayer Loadout: 1
async function prayerLoadoutSelection(player) {
    if (getPlayerScore("prayer_active", player) == 1) {
        prayersActive(player);
    }
    else {
        const form = new ActionFormData()
            .title("\§9Prayer \§6Loadout \§rSelection")
            .body(`Select \§6Loadout\§r (Current \§6Loadout: ${getPlayerScore("current_load", player)})`)
        form.button(`\§6Loadout 1 \n\§7Slot 1: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_1`, player)]}\n\§7Slot 2: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_2`, player)]}\n\§7Slot 3: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_3`, player)]}`);
        form.button(`\§6Loadout 2 \n\§7Slot 1: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_4`, player)]}\n\§7Slot 2: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_5`, player)]}\n\§7Slot 3: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_6`, player)]}`);
        form.button(`\§6Loadout 3 \n\§7Slot 1: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_7`, player)]}\n\§7Slot 2: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_8`, player)]}\n\§7Slot 3: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_9`, player)]}`);
        const response = await form.show(player)

        if (!response.canceled) prayerLoadoutOptions(player, response.selection);
    }
    return;
}

//Prayers already active: 2, called from 1
async function prayersActive(player) {

    const form = new ActionFormData()
        .title(`\§9Prayer\§r Active`)
        .body(`You cannot modify \§9Prayers\§r while they are active!`)
        .button("Deactivate Prayers")
    const response = await form.show(player)

    //deactivate prayers
    if (response.selection == 0) {
        await player.runCommandAsync(`scoreboard players set @s prayer_active 0`);
        prayerLoadoutSelection(player);
    }

    return;
}

//Prayer Loadout Options: 3, called from 1
async function prayerLoadoutOptions(player, loadoutSlot) {

    const form = new ActionFormData()
        .title(`\§9Prayer \§6Loadout \§rOptions`)
        .body(`Select \§6Loadout ${loadoutSlot + 1} \§rOption`)
        .button("Equip")
        .button("Edit")
        .button("Clear")
        .button("Back")
    const response = await form.show(player);

    switch (response.selection) {
        //equip
        case 0:
            if (getPlayerScore("current_load", player) == (loadoutSlot + 1)) {
                alreadyEquipped(player, loadoutSlot);
                break;
            }
            else {
                equipLoadout(player, loadoutSlot);
                await player.runCommandAsync("testfor @s");
                prayerLoadoutSelection(player);
            }
            break;
        //edit
        case 1:
            prayerSlotSelection(player, loadoutSlot);
            break;
        //clear
        case 2:
            clearLoadout(player, loadoutSlot);
            break;
        //back
        case 3:
            prayerLoadoutSelection(player);
            break;
    }

    return;

}

//clearLoadout : 4, called from 3
async function clearLoadout(player, loadoutSlot) {
    const prayerCost = getPlayerScore("pray_tot_cost", player);
    if (prayerCost == 0) {
        prayerAlreadyCleared(player, loadoutSlot)
    }
    else {
        switch (loadoutSlot) {
            case 0:
                player.runCommandAsync("scoreboard players set @s prayer_slot_1 0");
                player.runCommandAsync("scoreboard players set @s prayer_slot_2 0");
                player.runCommandAsync("scoreboard players set @s prayer_slot_3 0");
                break;
            case 1:
                player.runCommandAsync("scoreboard players set @s prayer_slot_4 0");
                player.runCommandAsync("scoreboard players set @s prayer_slot_5 0");
                player.runCommandAsync("scoreboard players set @s prayer_slot_6 0");
                break;
            case 2:
                player.runCommandAsync("scoreboard players set @s prayer_slot_7 0");
                player.runCommandAsync("scoreboard players set @s prayer_slot_8 0");
                player.runCommandAsync("scoreboard players set @s prayer_slot_9 0");
                break;
        }
    }
    await player.runCommandAsync("testfor @s")
    equipLoadout(player, loadoutSlot);
    prayerLoadoutSelection(player);
    return;
}

//prayerAlreadyCleared: 5, called from 4
async function prayerAlreadyCleared(player, loadoutSlot) {

    const form = new ActionFormData()
        .title(`Empty \§9Prayer \§9Loadout\§r`)
        .body(`This \§9Prayers \§9Loadout\§r is already cleared!`)
        .button("Back")
    const response = await form.show(player)

    if (response.selection == 0) {
        prayerLoadoutOptions(player, loadoutSlot)
    }

    return;

}

//equipLoadout: 6, called from 3, 13
async function equipLoadout(player, loadoutSlot) {

    await player.runCommandAsync(`scoreboard players set @s current_load ${loadoutSlot + 1}`)
    switch (loadoutSlot) {
        case 0:
            player.runCommandAsync("scoreboard players operation @s current_pray_1 = @s prayer_slot_1");
            player.runCommandAsync("scoreboard players operation @s current_pray_2 = @s prayer_slot_2");
            player.runCommandAsync("scoreboard players operation @s current_pray_3 = @s prayer_slot_3");
            break;
        case 1:
            player.runCommandAsync("scoreboard players operation @s current_pray_1 = @s prayer_slot_4");
            player.runCommandAsync("scoreboard players operation @s current_pray_2 = @s prayer_slot_5");
            player.runCommandAsync("scoreboard players operation @s current_pray_3 = @s prayer_slot_6");
            break;
        case 2:
            player.runCommandAsync("scoreboard players operation @s current_pray_1 = @s prayer_slot_7");
            player.runCommandAsync("scoreboard players operation @s current_pray_2 = @s prayer_slot_8");
            player.runCommandAsync("scoreboard players operation @s current_pray_3 = @s prayer_slot_9");
            break;
    }
    calculateTotalCost(player, loadoutSlot)

    return;

}

//prayer loadout is already equipped: 7, called from 6
async function alreadyEquipped(player, loadoutSlot) {
    const form = new ActionFormData()
        .title(`\§9Prayer \§6Loadout\§r Already Equipped`)
        .body(`This \§9Prayers \§6Loadout\§r is already equipped!`)
        .button("Back")
    const response = await form.show(player)

    if (response.selection == 0) {
        prayerLoadoutOptions(player, loadoutSlot)
    }
    return;
}

//calculate total prayer cost: 8, called from 6
async function calculateTotalCost(player) {

    await player.runCommandAsync("scoreboard players set @s pray_tot_cost 0");
    const prayerOne = await getPlayerScore("current_pray_1", player);
    const prayerTwo = await getPlayerScore("current_pray_2", player);
    const prayerThree = await getPlayerScore("current_pray_3", player);

    if (prayerOne > 0) {
        if (prayerOne < 11) {
            player.runCommandAsync("scoreboard players add @s pray_tot_cost 4");
        }
        else {
            player.runCommandAsync("scoreboard players add @s pray_tot_cost 8");
        }
    }
    if (prayerTwo > 0) {
        if (prayerTwo < 11) {
            player.runCommandAsync("scoreboard players add @s pray_tot_cost 4");
        }
        else {
            player.runCommandAsync("scoreboard players add @s pray_tot_cost 8");
        }
    }
    if (prayerThree > 0) {
        if (prayerThree < 11) {
            player.runCommandAsync("scoreboard players add @s pray_tot_cost 4");
        }
        else {
            player.runCommandAsync("scoreboard players add @s pray_tot_cost 8");
        }
    }
    return;

}

//selecting which of the three prayer slots will be modified/looked at: 9, called from 3
async function prayerSlotSelection(player, loadoutSlot) {

    const form = new ActionFormData()
        .title(`\§9Prayer \§7Slot \§rSelection`)
        .body(`Select \§6Loadout ${loadoutSlot + 1} \§7Slot`)
    switch (loadoutSlot) {
        case 0:
            form.button(`\§7Slot 1: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_1`, player)]}`)
            form.button(`\§7Slot 2: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_2`, player)]}`)
            form.button(`\§7Slot 3: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_3`, player)]}`)
            break;
        case 1:
            form.button(`\§7Slot 1: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_4`, player)]}`)
            form.button(`\§7Slot 2: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_5`, player)]}`)
            form.button(`\§7Slot 3: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_6`, player)]}`)
            break;
        case 2:
            form.button(`\§7Slot 1: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_7`, player)]}`)
            form.button(`\§7Slot 2: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_8`, player)]}`)
            form.button(`\§7Slot 3: ${prayerNamesWithTier[getPlayerScore(`prayer_slot_9`, player)]}`)
            break;
    }
    form.button("Back")
    const response = await form.show(player);
    if (response.selection >= 0 && response.selection <= 2) {
        prayerSlotOptions(player, loadoutSlot, response.selection);
    }
    else if (response.selection == 3) {
        prayerLoadoutOptions(player, loadoutSlot);
    }
    return;

}

//selecting which slot to edit: 10, called from 9
async function prayerSlotOptions(player, loadoutSlot, prayerSlot) {

    const form = new ActionFormData()
        .title(`\§9Prayer \§7Slot \§rOptions`)
        .body(`Select \§6Loadout ${loadoutSlot + 1} \§7Slot ${prayerSlot + 1} \§rOption`)
        .button("Set \§9Prayer")
        .button("Clear \§7Slot")
        .button("Back")
    const response = await form.show(player);
    switch (response.selection) {
        case 0:
            displayPrayerList(player, loadoutSlot, prayerSlot);
            break;
        //clear slot
        case 1:
            checkIfEmpty(player, loadoutSlot, prayerSlot);
            break;
        //back
        case 2:
            prayerSlotSelection(player, loadoutSlot);
            break;
    }

    return;

}

//clearing a specific slot: 11, called from 10
async function checkIfEmpty(player, loadoutSlot, prayerSlot) {

    let prayer = 0;
    switch (loadoutSlot) {
        case 0:
            switch (prayerSlot) {
                case 0:
                    prayer = getPlayerScore(`prayer_slot_1`, player);
                    break;
                case 1:
                    prayer = getPlayerScore(`prayer_slot_2`, player);
                    break;
                case 2:
                    prayer = getPlayerScore(`prayer_slot_3`, player);
                    break;
            }
            break;
        case 1:
            switch (prayerSlot) {
                case 0:
                    prayer = getPlayerScore(`prayer_slot_4`, player);
                    break;
                case 1:
                    prayer = getPlayerScore(`prayer_slot_5`, player);
                    break;
                case 2:
                    prayer = getPlayerScore(`prayer_slot_6`, player);
                    break;
            }
            break;
        case 2:
            switch (prayerSlot) {
                case 0:
                    prayer = getPlayerScore(`prayer_slot_7`, player);
                    break;
                case 1:
                    prayer = getPlayerScore(`prayer_slot_8`, player);
                    break;
                case 2:
                    prayer = getPlayerScore(`prayer_slot_9`, player);
                    break;
            }
            break;
    }
    //slot is already empty
    if (prayer == 0) {
        slotAlreadyClear(player, loadoutSlot, prayerSlot);
    }
    //slot contains something and needs to be cleared 
    else {
        slotClear(player, loadoutSlot, prayerSlot);
        await player.runCommandAsync("testfor @s")
        prayerLoadoutSelection(player);
    }

    return;

}

//prayer slot is already empty: 12, called from 11
async function slotAlreadyClear(player, loadoutSlot, prayerSlot) {

    const form = new ActionFormData()
        .title(`Empty \§9Prayer\§r \§7Slot`)
        .body(`This \§9Prayer\§r \§7slot\§r is already empty!`)
        .button("Back")
    const response = await form.show(player)

    if (response.selection == 0) {
        prayerSlotOptions(player, loadoutSlot, prayerSlot)
    }

    return;

}

//clear the actual slot after checking if it was already empty: 13, called from 10, 16
async function slotClear(player, loadoutSlot, prayerSlot) {

    switch (loadoutSlot) {
        case 0:
            player.runCommandAsync(`scoreboard players set @s prayer_slot_${prayerSlot + 1} 0`)
            break;
        case 1:
            player.runCommandAsync(`scoreboard players set @s prayer_slot_${prayerSlot + 4} 0`)
            break;
        case 2:
            player.runCommandAsync(`scoreboard players set @s prayer_slot_${prayerSlot + 7} 0`)
            break;
    }
    if ((loadoutSlot + 1) == getPlayerScore("current_load", player)) {
        equipLoadout(player, loadoutSlot);
    }

    return;

}
//select a prayer to put in the slot: 14, called from 10, 16
async function displayPrayerList(player, loadoutSlot, prayerSlot) {

    //get prayer level to determine outputs
    const prayerLevel = getPlayerScore("prayer_level", player);

    const buttonOutputs = {
        "§dJump Boost 1 §a[Tier 1]": 5,
        "§dStamina Regeneration 1 §a[Tier 1]": 9,
        "§dRegeneration 1 §a[Tier 1]": 13,
        "§dSpeed 1 §a[Tier 1]": 17,
        "§dStrength 1 §a[Tier 1]": 21,
        "§dResistance 1 §a[Tier 1]": 25,
        "§dLevitation 1 §a[Tier 1]": 29,
        "§dSlow Falling 1 §a[Tier 1]": 33,
        "§dWater Breathing 1 §a[Tier 1]": 37,
        "§dInvisibility 1 §a[Tier 1]": 41,
        "§dFire Resistance 1 §b[Tier 2]": 45,
        "§dJump Boost 2 §b[Tier 2]": 49,
        "§dStamina Regeneration 2 §b[Tier 2]": 53,
        "§dRegeneration 2 §b[Tier 2]": 57,
        "§dSpeed 2 §b[Tier 2]": 61,
        "§dStrength 2 §b[Tier 2]": 65,
        "§dResistance 2 §b[Tier 2]": 69,
        "§dHaste 1 §b[Tier 2]": 73
    }
    const form = new ActionFormData()
        .title("\§bPrayer\§r Selection")
        .body(`Select \§bPrayer \§rfor \§6Loadout ${loadoutSlot + 1} \§7Slot ${prayerSlot + 1}`)
    let count = 0;
    for (const text in buttonOutputs) {
        if (prayerLevel > buttonOutputs[text]) {
            count++;
            form.button(text);

        }
    }
    form.button("Back")
    const response = await form.show(player);

    //check if the player has tried to equip the same prayer to the same slot
    if (response.selection != count && !response.canceled) {
        switch (loadoutSlot) {
            case 0:
                checkIfSamePrayer(player, loadoutSlot, prayerSlot, response.selection, getPlayerScore("prayer_slot_1", player), getPlayerScore("prayer_slot_2", player), getPlayerScore("prayer_slot_3", player));
                break;
            case 1:
                checkIfSamePrayer(player, loadoutSlot, prayerSlot, response.selection, getPlayerScore("prayer_slot_4", player), getPlayerScore("prayer_slot_5", player), getPlayerScore("prayer_slot_6", player));
                break;
            case 2:
                checkIfSamePrayer(player, loadoutSlot, prayerSlot, response.selection, getPlayerScore("prayer_slot_7", player), getPlayerScore("prayer_slot_8", player), getPlayerScore("prayer_slot_9", player));
                break;
        }
    }
    else {
        prayerSlotOptions(player, loadoutNumber, prayerSlot);
    }

    return;

}

//checking to see if the player is equipping a prayer to a different slot in the same loadout: 15, called from 14
async function checkIfSamePrayer(player, loadoutSlot, prayerSlot, selectedPrayer, currentPrayer1, currentPrayer2, currentPrayer3) {

    if ((selectedPrayer + 1) == currentPrayer1) {
        samePrayer(player, loadoutSlot, prayerSlot, 0, selectedPrayer)
    }
    else if ((selectedPrayer + 1) == currentPrayer2) {
        samePrayer(player, loadoutSlot, prayerSlot, 1, selectedPrayer);
    }
    else if ((selectedPrayer + 1) == currentPrayer3) {
        samePrayer(player, loadoutSlot, prayerSlot, 2, selectedPrayer);
    }
    else if ((selectedPrayer + 1) > 10) {
        checkIfTierTwoPrayer(player, loadoutSlot, prayerSlot, selectedPrayer, currentPrayer1, currentPrayer2, currentPrayer3)
    }
    else {
        setPrayer(player, loadoutSlot, prayerSlot, selectedPrayer)
    }

    return;

}

//tell the player they have the same prayer equipped to the same slot, or a different slot: 16, called from 15
async function samePrayer(player, loadoutSlot, prayerSlot, prayerSlotWithDuplicate, selectedPrayer) {

    const form = new ActionFormData()
        .title("Same Prayer Detected")

    if (prayerSlot == prayerSlotWithDuplicate) {
        form.body(`\§d${prayerNamesWithTier[selectedPrayer]}\§r is already equipped to this \§9Slot\§r.`)
        form.button("Back")
        const response = await form.show(player)
        if (response.selection == 0) {
            displayPrayerList(player, loadoutSlot, prayerSlot);
        }
    }
    else {
        form.body(`\§d${prayerNamesWithTier[selectedPrayer + 1]}\§r is already equipped to \§7 Slot ${prayerSlotWithDuplicate + 1}.`)
        form.button(`Move \§bPrayer \§rto \§7Slot ${prayerSlot + 1}`)
        form.button("Back")
        const response = await form.show(player)

        switch (response.selection) {
            //move prayer
            case 0:
                slotClear(player, loadoutSlot, prayerSlotWithDuplicate);
                setPrayer(player, loadoutSlot, prayerSlot, selectedPrayer);
                break;
            //go back
            case 1:
                displayPrayerList(player, loadoutNumber, prayerSlot);
                break;
        }
    }

    return;

}

//Check if the player has a tier two prayer already equipped (They are only allowed a Max of 1: 17, called from 15)
async function checkIfTierTwoPrayer(player, loadoutSlot, prayerSlot, selectedPrayer, prayer1, prayer2, prayer3) {

    switch (prayerSlot) {
        case 0:
            //need to remove prayer in second slot
            if (prayer2 > 10) {
                //VERIFY OPTION PARAMETERS: PLAYER, CURRENT LOADOUTSLOT, CURRENT PRAYER SLOT, SLOT WITH OTHER TIER 2, CHOSEN PRAYER, 
                await verifyOption(player, loadoutSlot, prayerSlot, selectedPrayer, prayer2, 1)

            }
            //need to remove prayer in third slot
            else if (prayer3 > 10) {
                await verifyOption(player, loadoutSlot, prayerSlot, selectedPrayer, prayer3, 2)
            }
            else {
                setPrayer(player, loadoutSlot, prayerSlot, selectedPrayer)
            }
            break;
        case 1:
            //need to remove prayer in second slot
            if (prayer1 > 10) {
                await verifyOption(player, loadoutSlot, prayerSlot, selectedPrayer, prayer1, 0)
            }
            //need to remove prayer in third slot
            else if (prayer3 > 10) {
                await verifyOption(player, loadoutSlot, prayerSlot, selectedPrayer, prayer3, 2)
            }
            else {
                setPrayer(player, loadoutSlot, prayerSlot, selectedPrayer)
            }
            break;
        case 2:
            //need to remove prayer in second slot
            if (prayer1 > 10) {
                await verifyOption(player, loadoutSlot, prayerSlot, selectedPrayer, prayer1, 0)
            }
            //need to remove prayer in third slot
            else if (prayer2 > 10) {
                await verifyOption(player, loadoutSlot, prayerSlot, selectedPrayer, prayer2, 1)
            }
            else {
                setPrayer(player, loadoutSlot, prayerSlot, selectedPrayer)
            }
            break;
    }

    return;

}

//verify that the player wants to delete the other tier 2 prayer and equip the new one in the selected slot: 18, called from 17
async function verifyOption(player, loadoutSlot, prayerSlot, selectedPrayer, prayerToRemove, prayerToRemoveSlot) {

    const form = new ActionFormData()
        .title("Conflicting Prayer Selection")
        .body(`You are attempting to slot a Prayer into \§6Loadout ${loadoutSlot + 1}\§7 Slot ${prayerSlot + 1}.\n\n\§rOnly one \§bTier 2 \§9Prayer \§rmay be allocated at a time. \§d${prayerNamesWithTier[selectedPrayer + 1]} \§r will replace \§d${prayerNamesWithTier[prayerToRemove]}\§r located in \§7Slot ${prayerToRemoveSlot + 1}.\n\n\§rDo you wish to proceed?`)
        .button("Yes")
        .button("Back")
    const response = await form.show(player);
    switch (response.selection) {
        case 0:
            slotClear(player, loadoutSlot, prayerToRemoveSlot);
            setPrayer(player, loadoutSlot, prayerSlot, selectedPrayer);
            break;
        case 1:
            displayPrayerList(player, loadoutSlot, prayerSlot);
            break;
    }

    return;

}

//function to set prayer scoreboard values
async function setPrayer(player, loadoutSlot, prayerSlot, selectedPrayer) {
    switch (loadoutSlot) {
        case 0:
            player.runCommandAsync(`scoreboard players set @s prayer_slot_${prayerSlot + 1} ${selectedPrayer + 1}`);
            break;
        case 1:
            player.runCommandAsync(`scoreboard players set @s prayer_slot_${prayerSlot + 4} ${selectedPrayer + 1}`);
            break;
        case 2:
            player.runCommandAsync(`scoreboard players set @s prayer_slot_${prayerSlot + 7} ${selectedPrayer + 1}`);
            break;
    }
    if((loadoutSlot + 1) == getPlayerScore("current_load", player)) {
        equipLoadout(player, loadoutSlot);
    }
    await player.runCommandAsync("testfor @s");
    prayerLoadoutSelection(player);
    return;

}